/****************************************************************************
**      DISCLAIMER  
**  
**   Novell, Inc. makes no representations or warranties with respect to
**   any NetWare software, and specifically disclaims any express or
**   implied warranties of merchantability, title, or fitness for a
**   particular purpose.  
**
**   Distribution of any NetWare software is forbidden without the
**   express written consent of Novell, Inc.  Further, Novell reserves
**   the right to discontinue distribution of any NetWare software.
**   
**   Novell is not responsible for lost profits or revenue, loss of use
**   of the software, loss of data, costs of re-creating lost data, the
**   cost of any substitute equipment or program, or claims by any party
**   other than you.  Novell strongly recommends a backup be made before
**   any software is installed.   Technical support for this software
**   may be provided at the discretion of Novell.
****************************************************************************
**
**   File: SERVADDR.C
**
**   Desc: This program demostrates how to get the internal network address
**         from a specified server by reading that servers property from the
**         bindery of the server the connection handle is gotten from.
**         NOTE: NWGetDefaultConnetionID() could be used to get the default
**               connHandle thus reading the default bindery.
**
**
**   Parameter descriptions:    > input
**                              < output
**
**
**   Programmers:
**   Ini   Who                Firm
**   ------------------------------------------------------------------
**   ARM   A. Ray Maxwell     Novell Developer Support.
**
**   History:
**
**   ------------------------------------------------------------------
**   12-16-94   ARM   First code.
*/

/***************************************************************************
**   Include headers, macros, function prototypes, etc.
*/

   /*------------------------------------------------------------------
   **   ANSI
   */

   #include <stdlib.h>          /* exit(), atol()        */
   #include <stdio.h>           /* sprintf()             */
   #include <string.h>


   /*------------------------------------------------------------------
   **   NetWare
   */
   #define NWDOS
   #define SIZEOFOBJNAME 48
   #define SEGSIZE 128
   #define SIZEOFPROPNAME 15
   
   #include <nwcalls.h>



/***************************************************************************
**   Program Start
*/
void main(int argc, char *argv[])
{
   NWCCODE        ccode;
   NWCONN_HANDLE  connHandle;
   NWOBJ_TYPE     objectType;
   NWSEGMENT_NUM  dataSetIndex = 1;    /* init to one on the first pass */
   NWSEGMENT_NUM  dataBuffer[SEGSIZE]; /* SEGSIZE is 128 bytes          */
   NWFLAGS        valueMoreFlag;
   NWFLAGS        propertyFlags;
   char           objectName[SIZEOFOBJNAME];
   char           serverName[SIZEOFOBJNAME];
   char           propertyName[SIZEOFPROPNAME];


   memset( dataBuffer, '\0', sizeof(dataBuffer) );

   if(argc != 4) {
      printf("Usage:SERVADDR <servername> <object name> <objectType>\n\n");
      printf("     Server name:  Name of server to get connhandle to\n");
      printf("     OBJECT NAME:  Name of object i.e the server name\n");
      printf("     OBJECT TYPE:  4 for server\n");
      exit(1);
   }

   strcpy(serverName,  strupr(argv[1]));
   strcpy(objectName, strupr(argv[2]));
   objectType= NWWordSwap(atoi(argv[3]));
   strcpy(propertyName,"NET_ADDRESS");
   ccode = NWCallsInit( NULL, NULL );
   if (ccode)
   {
      printf( "\nNWCallsInit: failed %04x", ccode );
      exit(1);
   }
   ccode = NWGetConnectionHandle(
           /* > servername        */ serverName,
           /*   Novell Reserved1  */ 0,
           /* < connection handle */ &connHandle,
           /*   Novell Reserved2  */ NULL);
      
   if (ccode)
   {
      printf( "\nNWGetConnectionHandle: failed %04x", ccode );
      exit(1);
   }


   ccode=NWReadPropertyValue(
         /* > conn HANDLE                   */ connHandle,
         /* > Pointer object name           */ &objectName,
         /* > object type                   */ objectType,
         /* > pointer name of property      */ &propertyName,
         /* > segment number of data        */ dataSetIndex,
         /* < pointer 128 byte receive buf  */ dataBuffer,
         /* < pointer to flag               */ &valueMoreFlag,
         /* < pointer property type   (opt) */ &propertyFlags);
   if (ccode){
      printf("NWReadPropertyValue failed: %X\n",ccode);
      exit(1);
   }    


   printf("\n Net Address = %08lx", NWLongSwap(*(long *)dataBuffer));


} /* end of main */

                                                                  
                                                                                                                                                              
